local eventFrame = CreateFrame("frame")
eventFrame:SetScript("OnEvent", function(self, event, addon)
	-- check if an item that's about to be deleted should be protected
	if event == "DELETE_ITEM_CONFIRM" then
		local cursorType, _, link = GetCursorInfo()
		if cursorType == "item" then
			local lowerName = link:match("%[(.-)]"):lower()
			if lowerName and ItemProtectorOrDestroyerSave.protectedItems[lowerName] then
				ClearCursor()
				DEFAULT_CHAT_FRAME:AddMessage(link .. " was protected by ItemProtectorOrDestroyer!", 1, 0, 0)
			end
		end
		return
	end

	-- check if an item that was just sold should be bought back
	if event == "MERCHANT_UPDATE" then
		local name
		local protectedItems = ItemProtectorOrDestroyerSave.protectedItems
		for i=1,GetNumBuybackItems() do
			name = (GetBuybackItemInfo(i))
			if name and protectedItems[name:lower()] then
				BuybackItem(i)
				DEFAULT_CHAT_FRAME:AddMessage(GetBuybackItemLink(i) .. " was bought back by ItemProtectorOrDestroyer!", 1, 0, 0)
			end
		end
		return
	end

	-- set up default settings if needed
	if event == "ADDON_LOADED" then
		if addon == "ItemProtectorOrDestroyer" then
			self:UnregisterEvent(event)
			ItemProtectorOrDestroyerSave = ItemProtectorOrDestroyerSave or {}
			local settings = ItemProtectorOrDestroyerSave
			if settings.autoTypeDelete == nil then settings.autoTypeDelete = true end
			if settings.protectedItems == nil then settings.protectedItems = {}   end
		end
		return
	end
end)
eventFrame:RegisterEvent("ADDON_LOADED")        -- temporary - to initialize settings
eventFrame:RegisterEvent("DELETE_ITEM_CONFIRM") -- to check when trying to destroy an item
eventFrame:RegisterEvent("MERCHANT_UPDATE")     -- to check a merchant's buyback items

-- Automatically type DELETE on item destroy popups if wanted
hooksecurefunc(StaticPopupDialogs["DELETE_GOOD_ITEM"], "OnShow", function(self)
	if ItemProtectorOrDestroyerSave.autoTypeDelete then
		self.editBox:SetText(DELETE_ITEM_CONFIRM_STRING)
	end
end)
